/*
 * Copyright (C) 2007  Enrico Zini <enrico@enricozini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#include <tests/test-utils.h>
#include <pkg/package.h>

namespace tut {
using namespace std;
using namespace pkg;

struct pkg_package_shar {
};
TESTGRP(pkg_package);

// Basic test for invalid package
template<> template<>
void to::test<1>()
{
	Package test;

	ensure_equals(test.name(), "");
	ensure_equals(test.version(), "");
	ensure_equals(test.isValid(), false);
	ensure_equals(test.hasVersion(), false);
}

// Basic test for versionless package
template<> template<>
void to::test<2>()
{
	Package test("test");

	ensure_equals(test.name(), "test");
	ensure_equals(test.version(), "");
	ensure_equals(test.isValid(), true);
	ensure_equals(test.hasVersion(), false);
}

// Basic test for package with version
template<> template<>
void to::test<3>()
{
	Package test("test", "1.0");

	ensure_equals(test.name(), "test");
	ensure_equals(test.version(), "1.0");
	ensure_equals(test.isValid(), true);
	ensure_equals(test.hasVersion(), true);
}

// Comparison semanthics, package without version
template<> template<>
void to::test<4>()
{
	Package test("test");
	Package test1("test");

	ensure(test == test1);
	ensure(! (test != test1));
	ensure(! (test < test1));
	ensure(! (test > test1));
	ensure(test <= test1);
	ensure(test >= test1);


	Package test2("test2");

	ensure(test != test2);
	ensure(test != test2);
	ensure(test < test2);
	ensure(! (test > test2));
	ensure(test <= test2);
	ensure(! (test >= test2));
}

// Comparison semanthics, package with version
template<> template<>
void to::test<5>()
{
	Package test("test", "1.0");
	Package test1("test", "1.0");

	ensure(test == test1);
	ensure(! (test != test1));
	ensure(! (test < test1));
	ensure(! (test > test1));
	ensure(test <= test1);
	ensure(test >= test1);


	Package test2("test2", "1.0");

	ensure(test != test2);
	ensure(test != test2);
	ensure(test < test2);
	ensure(! (test > test2));
	ensure(test <= test2);
	ensure(! (test >= test2));


	Package test3("test", "2.0");

	ensure(test != test3);
	ensure(test != test3);
	ensure(test < test3);
	ensure(! (test > test3));
	ensure(test <= test3);
	ensure(! (test >= test3));
}

// Value-copy semanthics, package without version
template<> template<>
void to::test<6>()
{
	Package test("test");
	Package test1 = test;

	ensure(test == test1);

	Package test2;
	test2 = test;
	ensure(test == test2);
	ensure(test1 == test2);

	Package test3("test");
	ensure(test == test3);
	ensure(test1 == test3);
	ensure(test2 == test3);
}

// Value-copy semanthics, package with version
template<> template<>
void to::test<7>()
{
	Package test("test", "1.0");
	Package test1 = test;

	ensure(test == test1);

	Package test2;
	test2 = test;
	ensure(test == test2);
	ensure(test1 == test2);

	Package test3("test", "1.0");
	ensure(test == test3);
	ensure(test1 == test3);
	ensure(test2 == test3);
}

}

// vim:set ts=4 sw=4:
